// Package githubv4 is a client library for accessing GitHub
// GraphQL API v4 (https://docs.github.com/en/graphql).
//
// If you're looking for a client library for GitHub REST API v3,
// the recommended package is github.com/google/go-github/github.
//
// For now, see README for more details.
package githubv4 // import "github.com/shurcooL/githubv4"

//go:generate go run gen.go
